==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/my.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "လုပ်ဆောင်မှု",
    "An error occurred while loading activities" : "ဆောင်ရွက်မှုများ လုပ်ဆောင်နေစဉ် ပြဿနာတစ်ခု ကြုံတွေ့ခဲ့သည်",
    "No activity yet" : "လုပ်ဆောင်မှုမရှိသေး",
    "Load more activities" : "လုပ်ဆောင်မှုများ ပိုမိုပြသရန်",
    "Copied!" : "ကူးယူပြီး!",
    "Not supported!" : "အထောက်အပံ့ မပြု!",
    "Press ⌘-C to copy." : "ကူးယူရန်အတွက် ⌘-C ကိုနှိပ်ပါ။",
    "Press Ctrl-C to copy." : "ကူးယူရန်အတွက် Ctrl-C ကိုနှိပ်ပါ။",
    "{name} (restricted)" : "{name} (ကန့်သတ်ထား)",
    "in {path}" : "{path} တွင်",
    "This stream will show events like additions, changes & shares" : "ဤ လမ်းကြောင်းသည်  ပေါင်းထည့်ခြင်း၊ ပြောင်းလဲခြင်းနှင့် မျှဝေခြင်း စသည့် အဖြစ်အပျက်များကို ပြသပေးပါမည်။",
    "There are no events for this filter" : "ဤ စစ်ထုတ်မှုအတွက် ဖြစ်စဉ် တစ်ခုမှမရှိပါ။",
    "Today" : "ယနေ့",
    "Yesterday" : "မနေ့က",
    "Open file" : "ဖိုင်ဖွင့်ရန်",
    "Personal activity feed for %s" : "%sအတွက် ကိုယ်ပိုင် လုပ်ဆောင်မှု ပေးပို့ချက်",
    "Your feed URL is invalid" : "သင်၏ ပေးပို့ချက် URL မှားယွင်းနေသည်။",
    "Your settings have been updated." : "သင်၏ ပြင်ဆင်ချက်များကို မွမ်းမံပြီးဖြစ်သည်။",
    "Settings have been updated." : "ပြင်ဆင်ချက်များ မွမ်းမံပြီးပြီ။",
    "All activities" : "လုပ်ဆောင်ချက်အားလုံး",
    "By others" : "အခြားသူများမှ",
    "By you" : "သင့်ထံမှ",
    "\"remote user\"" : "\"အဝေးမှ အသုံးပြုသူ\"",
    "Activity notification for %s" : "%sအတွက် လုပ်ဆောင်မှု အသိပေးချက်",
    "Hello %s" : "မင်္ဂလာပါ %s",
    "Hello %s," : "မင်္ဂလာပါ %s၊",
    "There was some activity at %s" : "%sက လုပ်ဆောင်မှု အချို့ ရှိခဲ့သည်။",
    "_and %n more _::_and %n more _" : ["နှင့် အပို%n"],
    ", " : "၊",
    "%s and %s" : "%sနှင့် %s",
    "Mail" : "စာ",
    "Stream" : "လမ်းကြောင်း",
    "Activities" : "လုပ်ဆောင်မှုများ",
    "Home" : "ပင်မစာမျက်နှာ"
},
"nplurals=1; plural=0;");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/my.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "လုပ်ဆောင်မှု",
    "An error occurred while loading activities" : "ဆောင်ရွက်မှုများ လုပ်ဆောင်နေစဉ် ပြဿနာတစ်ခု ကြုံတွေ့ခဲ့သည်",
    "No activity yet" : "လုပ်ဆောင်မှုမရှိသေး",
    "Load more activities" : "လုပ်ဆောင်မှုများ ပိုမိုပြသရန်",
    "Copied!" : "ကူးယူပြီး!",
    "Not supported!" : "အထောက်အပံ့ မပြု!",
    "Press ⌘-C to copy." : "ကူးယူရန်အတွက် ⌘-C ကိုနှိပ်ပါ။",
    "Press Ctrl-C to copy." : "ကူးယူရန်အတွက် Ctrl-C ကိုနှိပ်ပါ။",
    "{name} (restricted)" : "{name} (ကန့်သတ်ထား)",
    "Home" : "ပင်မစာမျက်နှာ",
    "in {path}" : "{path} တွင်",
    "This stream will show events like additions, changes & shares" : "ဤ လမ်းကြောင်းသည်  ပေါင်းထည့်ခြင်း၊ ပြောင်းလဲခြင်းနှင့် မျှဝေခြင်း စသည့် အဖြစ်အပျက်များကို ပြသပေးပါမည်။",
    "There are no events for this filter" : "ဤ စစ်ထုတ်မှုအတွက် ဖြစ်စဉ် တစ်ခုမှမရှိပါ။",
    "Today" : "ယနေ့",
    "Yesterday" : "မနေ့က",
    "Open file" : "ဖိုင်ဖွင့်ရန်",
    "Personal activity feed for %s" : "%sအတွက် ကိုယ်ပိုင် လုပ်ဆောင်မှု ပေးပို့ချက်",
    "Your feed URL is invalid" : "သင်၏ ပေးပို့ချက် URL မှားယွင်းနေသည်။",
    "Your settings have been updated." : "သင်၏ ပြင်ဆင်ချက်များကို မွမ်းမံပြီးဖြစ်သည်။",
    "Settings have been updated." : "ပြင်ဆင်ချက်များ မွမ်းမံပြီးပြီ။",
    "All activities" : "လုပ်ဆောင်ချက်အားလုံး",
    "By others" : "အခြားသူများမှ",
    "By you" : "သင့်ထံမှ",
    "Activity notification for %s" : "%sအတွက် လုပ်ဆောင်မှု အသိပေးချက်",
    "Hello %s" : "မင်္ဂလာပါ %s",
    "Hello %s," : "မင်္ဂလာပါ %s၊",
    "There was some activity at %s" : "%sက လုပ်ဆောင်မှု အချို့ ရှိခဲ့သည်။",
    "_and %n more _::_and %n more _" : ["နှင့် အပို%n"],
    "Mail" : "စာ",
    "Stream" : "လမ်းကြောင်း",
    "Activities" : "လုပ်ဆောင်မှုများ",
    "\"remote user\"" : "\"အဝေးမှ အသုံးပြုသူ\"",
    ", " : "၊",
    "%s and %s" : "%sနှင့် %s"
},
"nplurals=1; plural=0;");
